OSSP CVS Repository

ossp - Difference in ossp-pkg/shiela/shiela.pl versions 1.18 and 1.19
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/shiela/shiela.pl 1.18 -> 1.19

--- shiela.pl    2002/12/21 09:42:57     1.18
+++ shiela.pl    2002/12/21 09:53:16     1.19
@@ -193,8 +193,8 @@
     my $v = `$RT->{cvs} --version 2>/dev/null`;
     $RT->{cvsvers} = '?';
     $RT->{cvsvers} = $1 if ($v =~ m|Concurrent\s+Versions\s+System\s+\(CVS\)\s+([\d.p]+)\s+|s);
-    $RT->{cvsossp} = 0;
-    $RT->{cvsossp} = 1 if ($v =~ m|OSSP|s);
+    $RT->{cvsrse} = 0;
+    $RT->{cvsrse} = 1 if ($v =~ m|\[RSE\]|s);
     die "$RT->{cvs} is not at least CVS 1.10" if ($RT->{cvsvers} !~ m|^1\.1[0-9]|);
     $RT->{useserver} = 0;
     $RT->{useserver} = 1 if ($v =~ m|server|s);
@@ -717,7 +717,7 @@
         "From: \"".$RT->{username}."\" <".$RT->{usermail}.">\n" .
         "To: $toaddr\n" .
         "User-Agent: ".uc(substr($RT->{name}, 0, 1)).substr($RT->{name}, 1)."/$RT->{vers} " .
-                     ($RT->{cvsossp} ? "OSSP-CVS" : "CVS")."/$RT->{cvsvers}\n" .
+                     "CVS/".$RT->{cvsvers}.($RT->{cvsrse} ? "+RSE" : "")."\n";
         "Precedence: bulk\n" .
         "Mime-Version: 1.0\n" .
         "Content-Type: text/plain; charset=iso-8859-1\n" . 
@@ -1244,7 +1244,7 @@
 ##  We hook into CVS via `commitinfo' to post-process log messages.
 ##  The intention is to sanitise the results of what the user may have
 ##  `done' while editing the commit log message. If CVS is a standard
 ##  version, this check is advisory only. If CVS contains the OSSP
 ##  patches, the log message is changed and CVS reads back the contents
 ##  so that this script can actually make changes.
 ##
@@ -1257,8 +1257,8 @@
     my ($PA, $RT, $CF) = @_;
     my $rv = 0;
 
-    #   we require the OSSP patches for operation
-    return $rv if (not $RT->{cvsossp});
+    #   we require the RSE patches for operation
+    return $rv if (not $RT->{cvsrse});
 
     #   suck in the log message
     my $logfile = $PA->{ARG}->[0];
@@ -1271,7 +1271,7 @@
     $data = &compress_message($data);
 
     #  update the log message
     #  (OSSP CVS reads in this again, stock CVS ignores it)
     open(FP, ">$logfile") || die "cannot open message file `$logfile' for writing";
     print FP $data;
     close(FP);
@@ -1378,7 +1378,7 @@
         #   N = new file
         #   U = updated w/o conflict
         #   C = updated w/  conflict
-        #   T = touched/tagged only (OSSP extension)
+        #   T = touched/tagged only (RSE extension)
         $RT->{cvsop} = 'import';
         @cvsinfo = ();
         $cvsmsg =~ s|Status:\n+Vendor Tag:\s+(\S+).*?\nRelease Tags:\s+(.+?)\s*\n(.+)$||s;
@@ -1456,8 +1456,8 @@
     &do_file('write', "$RT->{tmpfile}.log", '', $cvslog);
 
     #   if we are using a stock CVS version, we have to determine
-    #   extra information (which an OSSP CVS version would provide).
-    if (not $RT->{cvsossp} and not $RT->{cvsop} eq 'import') {
+    #   extra information (which an RSE CVS version would provide).
+    if (not $RT->{cvsrse} and not $RT->{cvsop} eq 'import') {
 
         #   parse CVS commit information
         my $tag = 'HEAD';
@@ -1244,7 +1244,7 @@
 ##  The intention is to sanitise the results of what the user may have
 ##  `done' while editing the commit log message. If CVS is a standard
-##  version, this check is advisory only. If CVS contains the OSSP
+##  version, this check is advisory only. If CVS contains the RSE
 ##  patches, the log message is changed and CVS reads back the contents
 ##  so that this script can actually make changes.
@@ -1271,7 +1271,7 @@
 
     #  update the log message
-    #  (OSSP CVS reads in this again, stock CVS ignores it)
+    #  (CVS with RSE patches reads in this again, stock CVS ignores it)
     open(FP, ">$logfile") || die "cannot open message file `$logfile' for writing";
     print FP $data;

CVSTrac 2.0.1